#############
# $Id: bowtie_runner.pm 13162 2011-05-13 08:58:15Z ajb $
# Created By: ajb
# Last Maintained By: $Author: ajb $
# Created On: 2009-07-08
# Last Changed On: $Date: 2011-05-13 09:58:15 +0100 (Fri, 13 May 2011) $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-pipeline/tags/release-27.0/lib/npg_pipeline/bowtie_runner.pm $

package npg_pipeline::bowtie_runner;
use Moose;
use Carp;
use English qw{-no_match_vars};
use Readonly; Readonly::Scalar our $VERSION => do { my ($r) = q$LastChangedRevision: 13162 $ =~ /(\d+)/mxs; $r; };

extends qw{npg_pipeline::base};
with qw{npg_common::roles::run::path_info};

Readonly::Scalar our $BOWTIE_PREFIX => q{bowtie};
Readonly::Scalar our $BOWTIE_EXE    => q{fake_swift};

sub run_bowtie {
  my ($self, @args) = @_;

  my $required_job_completion = shift @args;

  my $id_run      = $self->id_run();
  my $run_folder  = $self->run_folder();
  my $recalibrated_path   = $self->recalibrated_path();
  my $timestamp   = $self->timestamp();
  my $run_name    = $self->_detaint($self->_run->name(), qr/(\w+)/xms);
  my $job_name    = "bowtie_align_${run_name}";
  my $output_name = "$run_folder/$BOWTIE_PREFIX.$id_run.$timestamp.out";

  my ($bin_dir) = $PROGRAM_NAME =~ /(.*)\/[^\/]+\z/xms;    # executables from same directory as this one

  my $c_lane = $self->_get_control_lane();

  $ENV{LSB_DEFAULTPROJECT} ||= 'pipeline';     # required for bsub

  my @command = ();
  push @command, 'bsub';
  push @command, $required_job_completion;
  push @command, '-q normal';
  push @command, "-J $job_name";
  push @command, "-o $output_name";
  push @command, "$bin_dir/$BOWTIE_EXE";
  push @command, $id_run;
  push @command, $recalibrated_path;
  push @command, $c_lane;

  my $bowtie_command = join q[ ], @command;
  $self->util->log("bowtie command: $bowtie_command");

  my @from_lsf;

  if (exists $self->opts->{'test'}) {
    $self->util->log(q{(not run, --test flag set)});
  } else {

    @from_lsf = qx[$bowtie_command];
    croak "bowtie command failed: $CHILD_ERROR" if scalar @from_lsf == 0;

    chomp @from_lsf;
    $self->util->log('bsub output:');
    foreach my $line (@from_lsf) {
      $self->util->log("       | $line");
    }

  }

  return ($from_lsf[0]);

}

no Moose;
__PACKAGE__->meta->make_immutable;
1;
__END__

=head1 NAME

npg_pipeline::bowtie_runner

=head1 VERSION

$LastChangedRevision: 13162 $

=head1 SYNOPSIS

  my $oBowtieRunner = npg_pipeline::bowtie->new({
    id_run => $iIdRun,
    run_folder => $sRunFolder,
    recalibrated_path => $sPathToGerald,
    timestamp => $sTimeStamp,
  });

=head1 DESCRIPTION

=head1 SUBROUTINES/METHODS

=head2 run_bowtie - handler to perform the submission to LSF for running bowtie

  my @job_ids = $oBowtieRunner->run_bowtie($required_job_completion);

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

=over

=item Moose

=item Carp

=item English -no_match_vars

=back

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 AUTHOR

$Author: ajb $

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2010 GRL, by Andy Brown (ajb@sanger.ac.uk)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
