# $Id: 10-pluggable_harold_post_qc_review.t 13162 2011-05-13 08:58:15Z ajb $
use strict;
use warnings;
#use SangerPaths qw{trackingnpg};
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 7;
use Test::Deep;
use Test::Exception::LessClever;
use lib qw{t};
use t::util;
use File::Slurp;

my $util = t::util->new();
$util->catch_email();
my $conf_path = $util->conf_path();

my $runfolder_path = $util->analysis_runfolder_path();
$ENV{TEST_USERAGENT} = $runfolder_path . q{/useragent};

$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();
$ENV{OWNING_GROUP} = q{staff};

use_ok('npg_pipeline::pluggable::harold::post_qc_review');

$PROGRAM_NAME = q{npg_pipeline_post_qc_review};

{
  my $post_qc_review;
  my $functions_in_order = [qw(
    set_run_status_archival_in_progress
    archive_to_sra
    upload_illumina_analysis_to_qc_database
    upload_auto_qc_to_qc_database
    upload_summary_to_qc_database
    move_to_outgoing
    create_summary_link_outgoing
    set_run_status_run_archived
    set_run_status_qc_complete
    finish
    )];
  $util->set_staging_analysis_area({with_latest_summary => 1});
  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );

  lives_ok {
    $post_qc_review = npg_pipeline::pluggable::harold::post_qc_review->new({
      schema => q{harold::post_qc_review},
      id_run => 1234,
      function_order => $functions_in_order,
      run_folder => q{123456_IL2_1234},
      verbose => 1,
      analysis_path => q{Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto},
      conf_path => $conf_path,
      domain => q{test},
      no_spider => 1,
    });
  } q{no croak on creation};
  isa_ok($post_qc_review, q{npg_pipeline::pluggable::harold::post_qc_review}, q{$post_qc_review});
  is($post_qc_review->function_order(), $functions_in_order, q{$post_qc_review->function_order() set on creation});

  lives_ok {
    $post_qc_review->main();
  } q{no croak running harold->main()};

  my $recalibrated_path = $post_qc_review->recalibrated_path();
  $post_qc_review->make_log_dir( $recalibrated_path );
  my $webcache = $recalibrated_path . q{/archive/webcache};
  qx{mkdir -p $webcache};

  lives_ok {
    $post_qc_review->spider();
  } q{spider runs ok};
  is( $ENV{ npg_common::request->cache_dir_var_name() }, $webcache, q{environment variable set to webcache} );

}

1;