# $Id: 20-archive-file-fix_qseqs.t 13162 2011-05-13 08:58:15Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 8;
use Test::Exception;
use lib qw{t};
use t::util;

use_ok('npg_pipeline::archive::file::fix_qseqs');

my $util = t::util->new();
my $conf_path = $util->conf_path();

$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();

{
  my $f_qseq;

  lives_ok { $f_qseq = npg_pipeline::archive::file::fix_qseqs->new({
    run_folder => q{123456_IL2_1234},
    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
  }); } q{created object ok};
  isa_ok($f_qseq, q{npg_pipeline::archive::file::fix_qseqs}, q{$f_qseq});
  $util->create_analysis();
  my $arg_refs = {};
  $arg_refs->{required_job_completion}  = q{-w'done(123) && done(321)'};
  $arg_refs->{timestamp}                = q{20090709-123456};
  $arg_refs->{id_run}                   = 1234;
  $arg_refs->{BSUB_ERROR_FILE}          = q{substitute_this.err};
  $arg_refs->{BSUB_OUTPUT_FILE}         = q{substitute_this.out};

  $ENV{TEST_API_UTIL} = $util->apiutil();

  my @jids;
  lives_ok { @jids = $f_qseq->fix_qseqs($arg_refs); } q{submitted ok};

  my $generated_bsub_command = $util->drop_temp_part_from_paths( $f_qseq->_generate_bsub_command($arg_refs) );
  like($generated_bsub_command, qr{bsub[ ]-b[ ]\d{1,2}:\d{1,2}[ ]-q[ ]test[ ]-w'done[(]123[)][ ]&&[ ]done[(]321[)]'[ ]-J[ ]fix_qseq_run_id_1234_8_20090709-123456[ ]-R[ ]'rusage[[]nfs_12=1[]]'[ ]-o[ ]/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/fix_qseq_run_id_8_20090709-123456.out[ ]'t/bin/software/solexa/bin/fix_qseq_run_id[ ]-id_run=1234[ ]/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/s_8_1_qseq_custom.txt'}, q{generated bsub command is correct});

  is(scalar@jids, 8, q{8 job ids found});

  lives_ok { qx[perl -c bin/fix_qseq_run_id]; } q{perl -c ok};
  ok(!$CHILD_ERROR, q{bin/fix_qseq_run_id compiles ok});
}
1;