# $Id: 20-archive_file-summary.t 13162 2011-05-13 08:58:15Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 8;
use lib qw{t};
use Test::Exception;
use t::util;
use Digest::MD5;

use_ok('npg_pipeline::archive::file::summary');

my $util = t::util->new();
my $conf_path = $util->conf_path();

$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();
my $tmp_dir = $util->temp_directory();
$ENV{TEST_API_UTIL} = $util->apiutil();

{

  my $summary = npg_pipeline::archive::file::summary->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
  });
  isa_ok($summary, q{npg_pipeline::archive::file::summary}, q{$summary});

  $util->create_analysis();
  my $recalibrated_path = $summary->recalibrated_path();

  qx[cp t/data/summary_files/after_v7_mp_hack_Summary.htm $recalibrated_path/Summary.htm];
  qx[cp t/data/summary_files/after_v7_mp_hack_Summary.xml $recalibrated_path/Summary.xml];
  qx[cp t/data/summary_files/Summary.xsl $recalibrated_path/Summary.xsl];

  lives_ok { $summary->munge(); } q{munge runs ok};

  my $arg_refs = { required_job_completion => q{-w'done(123) & done(321)'} };

  my $job_sub = q{bsub -q test -R 'rusage[nfs_12=1]' -w'done(123) & done(321)' -J npg_pipeline_munge_summary_multiplex_1234_20090709-123456 };
  $job_sub   .= q{-o /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/log/npg_pipeline_munge_summary_multiplex_1234_20090709-123456.out };
  $job_sub   .= q{'t/bin/software/solexa/bin/npg_pipeline_munge_summary_multiplex };
  $job_sub   .= q{--basecall_path /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/BaseCalls };
  $job_sub   .= q{--bustard_path /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto };
  $job_sub   .= q{--conf_path data/config_files };
  $job_sub   .= q{--data_path /staging/IL2/analysis/123456_IL2_1234/Data };
  $job_sub   .= q{--domain test };
  $job_sub   .= q{--id_run 1234 };
  $job_sub   .= q{--intensity_path /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto };
  $job_sub   .= q{--name IL2_1234 };
  $job_sub   .= q{--pb_cal_path /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/PB_cal };
  $job_sub   .= q{--recalibrated_path /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto };
  $job_sub   .= q{--run_folder 123456_IL2_1234 };
  $job_sub   .= q{--runfolder_path /staging/IL2/analysis/123456_IL2_1234 };
  $job_sub   .= q{--tag_qseqs_path /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/tag_qseqs };
  $job_sub   .= q{--verbose '};

  is( $util->drop_temp_part_from_paths( $summary->_generate_bsub_command($arg_refs) ), $job_sub, q{job_sub created ok});

  my @job_ids;
  lives_ok { @job_ids = $summary->generate($arg_refs); } q{generate and submission of the bsub job ok};
  is(scalar@job_ids, 1, q{1 job id returned});

}
{
  my $summary = npg_pipeline::archive::file::summary->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
  });

  $util->create_analysis();
  my $recalibrated_path = $summary->recalibrated_path();

  qx[cp t/data/summary_files/after_v7_mp_hack_Summary.htm $recalibrated_path/Summary.htm];
  qx[cp t/data/summary_files/after_v7_mp_hack_Summary.xml $recalibrated_path/Summary.xml];
  qx[cp t/data/summary_files/Summary.xsl $recalibrated_path/Summary.xsl];
  lives_ok { qx[bin/npg_pipeline_munge_summary_multiplex --conf_path $conf_path --verbose  --basecall_path $tmp_dir/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/BaseCalls --lane_count 8 --tilelayout_rows 60 --intensity_path $tmp_dir/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto --bustard_path $tmp_dir/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto --expected_cycle_count 37 --qc_path $tmp_dir/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/qc --tilelayout_columns 2 --runfolder_path $tmp_dir/staging/IL2/analysis/123456_IL2_1234 --recalibrated_path $tmp_dir/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto --run_folder 123456_IL2_1234 --name IL2_1234 --data_path $tmp_dir/staging/IL2/analysis/123456_IL2_1234/Data --id_run 1234 --tag_qseqs_path $tmp_dir/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/tag_qseqs --archive_path $tmp_dir/staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive]; } q{munge_summary_multiplex};
  ok(!$CHILD_ERROR, qq{Error code ok : $CHILD_ERROR});
}

1;
__END__
