# $Id: 40-dispatch_tree.t 13162 2011-05-13 08:58:15Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 10;
use Test::Exception;
use lib qw{t};
use t::util;
use JSON;

use_ok('npg_pipeline::dispatch_tree');

my $util = t::util->new();
{
  my $tree;
  my $vars = {};
  lives_ok { $tree = npg_pipeline::dispatch_tree->new($vars); } q{tree object created ok};
  isa_ok($tree, q{npg_pipeline::dispatch_tree}, q{$tree});
  $vars->{functions} = [];
  is_deeply($tree->_data_structure(), $vars, q{returned data structure is correct - no vars except functions});
}
{
  my $tree;
  my $vars = {
    script_name => q{test_script_name},
    schema      => q{test_schema},
    run_folder  => q{test_runfolder},
    id_run      => q{1234},
    timestamp   => q{20090807-154037},
  };
  my $test_structure = \%{$vars};
  lives_ok { $tree = npg_pipeline::dispatch_tree->new($vars); } q{tree object created ok};
  $test_structure->{functions} = [];
  is_deeply($tree->_data_structure(), $test_structure, q{returned data structure is correct - vars present});
  my $function_info_one = {
    function          => q{function_one},
    job_ids_launched  => [1,2,3],
    job_dependencies  => q{},
  };
  push @{$test_structure->{functions}}, $function_info_one;
  $tree->append_to_functions($function_info_one);
  is_deeply($tree->_data_structure(), $test_structure, q{returned data structure includes function info});
  my $function_info_two = {
    function          => q{function_one},
    job_ids_launched  => [4,5,6],
    job_dependencies  => q{-w'done(1) && done(2) && done(3)'},
  };
  push @{$test_structure->{functions}}, $function_info_two;
  $tree->append_to_functions($function_info_two);
  my $json_structure = $tree->tree_as_json();
  my $href = from_json($json_structure);
  is_deeply($href, $test_structure, q{json structure is correct});

  my $new_tree;
  lives_ok { $new_tree = npg_pipeline::dispatch_tree->new({ json_structure => $json_structure }) ; } q{tree object created ok with a json_structure};
  is_deeply($tree, $new_tree, q{expected tree object built on construction});
}
1;